/// Contains main classes and main functionalities.
library git_assistant.main;

import 'package:meta/meta.dart';
import 'dart:io';

// Core part of the package
part 'src/core/base_git_chain.dart';

// Log command associated
part 'src/commands/git_log/log.dart';
part 'src/commands/git_log/log_option_data.dart';

/// Provides utilities to work with `git`.
///
/// ## Command Generator
/// Generates the command sequence in piece of cake.
/// ```dart
/// var git = Git();
/// print(git); // 'git'
/// print(git.log.prettyOpt(PF.oneline)); // 'git log --pretty=oneline'
/// ```
///
/// ## Command Executer
/// Executes the generated command sequence.
/// ```dart
/// var git = Git();
/// // executes 'git log --pretty=email' and returns the output
/// git.log.prettyOpt(PF.email).exec();
/// git.exec(); // executes 'git' and returns git help.
/// ```
class Git extends BaseGitChain {
  Git() : super('git');

  /// Git log command
  LogGitChain get log => LogGitChain('log', this);
}

// TODO[EhsanAramide]: Provide utilities to work with local git repository. {className: GitUtil}
