part of '../../../git_assistant.dart';

// TODO[EhsanAramide]: Provide a solution for number of last commit from head 'git log -1'.
// TODO[EhsanAramide]: Provide default parser for output logs.

/// Git log command class.
///
/// Provides log command options in simple way and recursive to be more like CLI.
///
/// ```dart
/// var git = Git();
/// print(git.log.prettyOpt(PF.full)); // 'git log --pretty=full'
/// git.log.exec(); // executes 'git log' and returns its output
/// ```
class LogGitChain extends BaseGitChain {
  LogGitChain(String chainName, BaseGitChain prevChain)
      : super(chainName, prevChain);

  LogGitChain _createLogOption(String chainName) {
    return LogGitChain(chainName, this);
  }

  /// Generates --pretty='format' or tformat:'format' option
  ///
  /// Takes one parameter which can be:
  /// 1. [PF] instance
  /// 2. or combination of [PP] instance and [String]
  ///
  /// ## Using [PF] for format option
  /// ```dart
  /// var git = Git();
  /// git.log.prettyOpt(PF.oneline).exec();
  /// print(git.log.prettyOpt(PF.email));
  /// git.log.prettyOpt(PF.fuller).exec();
  /// ```
  ///
  /// ## Using combination of [PP] and [String]
  /// ```dart
  /// var git = Git();
  /// // Executes 'git log --pretty=tformat:"commit %H"'
  /// git.log.prettyOpt('commit ${PP.commitHash.string}').exec();
  /// ```
  LogGitChain prettyOpt(dynamic format) {
    late String prettyChainName;
    if (format is PF) {
      prettyChainName = format.string;
    } else if (format is String) {
      prettyChainName = 'tformat:$format';
    } else {
      throw Exception(
        '[LogGitChain.prettyOpt]: "format" should String or PF enum instance',
      );
    }
    return _createLogOption('--pretty=$prettyChainName');
  }
}
